@@ -84,9 +84,9 @@ import org.apache.commons.net.io.ToNetASCIIInputStream;
 public class TFTPServer implements Runnable
 {
     private static final int DEFAULT_TFTP_PORT = 69;
-    public static enum ServerMode { GET_ONLY, PUT_ONLY, GET_AND_PUT; }
+    public enum ServerMode { GET_ONLY, PUT_ONLY, GET_AND_PUT; }
 
-    private final HashSet<TFTPTransfer> transfers_ = new HashSet<TFTPTransfer>();
+    private final HashSet<TFTPTransfer> transfers_ = new HashSet<>();
     private volatile boolean shutdownServer = false;
     private TFTP serverTftp_;
     private File serverReadDirectory_;
@@ -100,9 +100,9 @@ public class TFTPServer implements Runnable
     private static final PrintStream nullStream = new PrintStream(
             new OutputStream() {
                 @Override
-                public void write(int b){}
+                public void write(final int b){}
                 @Override
-                public void write(byte[] b) throws IOException {}
+                public void write(final byte[] b) throws IOException {}
                 }
             );
 
@@ -133,7 +133,7 @@ public class TFTPServer implements Runnable
      * @param mode A value as specified above.
      * @throws IOException if the server directory is invalid or does not exist.
      */
-    public TFTPServer(File serverReadDirectory, File serverWriteDirectory, ServerMode mode)
+    public TFTPServer(final File serverReadDirectory, final File serverWriteDirectory, final ServerMode mode)
             throws IOException
     {
         this(serverReadDirectory, serverWriteDirectory, DEFAULT_TFTP_PORT, mode, null, null);
@@ -158,13 +158,13 @@ public class TFTPServer implements Runnable
      * @param errorLog Stream to write error messages to. If not provided, uses System.err.
      * @throws IOException if the server directory is invalid or does not exist.
      */
-    public TFTPServer(File serverReadDirectory, File serverWriteDirectory, int port, ServerMode mode,
-            PrintStream log, PrintStream errorLog) throws IOException
+    public TFTPServer(final File serverReadDirectory, final File serverWriteDirectory, final int port, final ServerMode mode,
+            final PrintStream log, final PrintStream errorLog) throws IOException
     {
         port_ = port;
         mode_ = mode;
-        log_ = (log == null ? nullStream: log);
-        logError_ = (errorLog == null ? nullStream : errorLog);
+        log_ = log == null ? nullStream: log;
+        logError_ = errorLog == null ? nullStream : errorLog;
         laddr_ = null;
         launch(serverReadDirectory, serverWriteDirectory);
     }
@@ -189,15 +189,15 @@ public class TFTPServer implements Runnable
      * @param errorLog Stream to write error messages to. If not provided, uses System.err.
      * @throws IOException if the server directory is invalid or does not exist.
      */
-    public TFTPServer(File serverReadDirectory, File serverWriteDirectory, int port,
-        InetAddress localaddr, ServerMode mode, PrintStream log, PrintStream errorLog)
+    public TFTPServer(final File serverReadDirectory, final File serverWriteDirectory, final int port,
+        final InetAddress localaddr, final ServerMode mode, final PrintStream log, final PrintStream errorLog)
         throws IOException
     {
         port_ = port;
         mode_ = mode;
         laddr_ = localaddr;
-        log_ = (log == null ? nullStream: log);
-        logError_ = (errorLog == null ? nullStream : errorLog);
+        log_ = log == null ? nullStream: log;
+        logError_ = errorLog == null ? nullStream : errorLog;
         launch(serverReadDirectory, serverWriteDirectory);
     }
 
@@ -222,8 +222,8 @@ public class TFTPServer implements Runnable
      * @param errorLog Stream to write error messages to. If not provided, uses System.err.
      * @throws IOException if the server directory is invalid or does not exist.
      */
-    public TFTPServer(File serverReadDirectory, File serverWriteDirectory, int port,
-        NetworkInterface localiface, ServerMode mode, PrintStream log, PrintStream errorLog)
+    public TFTPServer(final File serverReadDirectory, final File serverWriteDirectory, final int port,
+        final NetworkInterface localiface, final ServerMode mode, final PrintStream log, final PrintStream errorLog)
         throws IOException
     {
         mode_ = mode;
@@ -231,14 +231,16 @@ public class TFTPServer implements Runnable
         InetAddress iaddr = null;
         if (localiface != null)
         {
-            Enumeration<InetAddress> ifaddrs = localiface.getInetAddresses();
+            final Enumeration<InetAddress> ifaddrs = localiface.getInetAddresses();
             if (ifaddrs != null)
             {
-                if (ifaddrs.hasMoreElements()) iaddr = ifaddrs.nextElement();
+                if (ifaddrs.hasMoreElements()) {
+                    iaddr = ifaddrs.nextElement();
+                }
             }
         }
-        log_ = (log == null ? nullStream: log);
-        logError_ = (errorLog == null ? nullStream : errorLog);
+        log_ = log == null ? nullStream: log;
+        logError_ = errorLog == null ? nullStream : errorLog;
         laddr_ = iaddr;
         launch(serverReadDirectory, serverWriteDirectory);
     }
@@ -248,7 +250,7 @@ public class TFTPServer implements Runnable
      *
      * @param retries number of retries, must be &gt; 0
      */
-    public void setMaxTimeoutRetries(int retries)
+    public void setMaxTimeoutRetries(final int retries)
     {
         if (retries < 0)
         {
@@ -272,7 +274,7 @@ public class TFTPServer implements Runnable
      * (5000 at the time I write this) Min value of 10.
      * @param timeout the timeout; must be larger than 10
      */
-    public void setSocketTimeout(int timeout)
+    public void setSocketTimeout(final int timeout)
     {
         if (timeout < 10)
         {
@@ -293,7 +295,7 @@ public class TFTPServer implements Runnable
     /*
      * start the server, throw an error if it can't start.
      */
-    private void launch(File serverReadDirectory, File serverWriteDirectory) throws IOException
+    private void launch(final File serverReadDirectory, final File serverWriteDirectory) throws IOException
     {
         log_.println("Starting TFTP Server on port " + port_ + ".  Read directory: "
                 + serverReadDirectory + " Write directory: " + serverWriteDirectory
@@ -365,18 +367,18 @@ public class TFTPServer implements Runnable
 
                 tftpPacket = serverTftp_.receive();
 
-                TFTPTransfer tt = new TFTPTransfer(tftpPacket);
+                final TFTPTransfer tt = new TFTPTransfer(tftpPacket);
                 synchronized(transfers_)
                 {
                     transfers_.add(tt);
                 }
 
-                Thread thread = new Thread(tt);
+                final Thread thread = new Thread(tt);
                 thread.setDaemon(true);
                 thread.start();
             }
         }
-        catch (Exception e)
+        catch (final Exception e)
         {
             if (!shutdownServer)
             {
@@ -404,7 +406,7 @@ public class TFTPServer implements Runnable
 
         synchronized(transfers_)
         {
-            Iterator<TFTPTransfer> it = transfers_.iterator();
+            final Iterator<TFTPTransfer> it = transfers_.iterator();
             while (it.hasNext())
             {
                 it.next().shutdown();
@@ -415,14 +417,14 @@ public class TFTPServer implements Runnable
         {
             serverTftp_.close();
         }
-        catch (RuntimeException e)
+        catch (final RuntimeException e)
         {
             // noop
         }
 
         try {
             serverThread.join();
-        } catch (InterruptedException e) {
+        } catch (final InterruptedException e) {
             // we've done the best we could, return
         }
     }
@@ -438,7 +440,7 @@ public class TFTPServer implements Runnable
 
         TFTP transferTftp_ = null;
 
-        public TFTPTransfer(TFTPPacket tftpPacket)
+        public TFTPTransfer(final TFTPPacket tftpPacket)
         {
             tftpPacket_ = tftpPacket;
         }
@@ -450,7 +452,7 @@ public class TFTPServer implements Runnable
             {
                 transferTftp_.close();
             }
-            catch (RuntimeException e)
+            catch (final RuntimeException e)
             {
                 // noop
             }
@@ -470,7 +472,7 @@ public class TFTPServer implements Runnable
 
                 if (tftpPacket_ instanceof TFTPReadRequestPacket)
                 {
-                    handleRead(((TFTPReadRequestPacket) tftpPacket_));
+                    handleRead((TFTPReadRequestPacket) tftpPacket_);
                 }
                 else if (tftpPacket_ instanceof TFTPWriteRequestPacket)
                 {
@@ -481,7 +483,7 @@ public class TFTPServer implements Runnable
                     log_.println("Unsupported TFTP request (" + tftpPacket_ + ") - ignored.");
                 }
             }
-            catch (Exception e)
+            catch (final Exception e)
             {
                 if (!shutdownTransfer)
                 {
@@ -500,7 +502,7 @@ public class TFTPServer implements Runnable
                         transferTftp_.close();
                     }
                 }
-                catch (Exception e)
+                catch (final Exception e)
                 {
                     // noop
                 }
@@ -514,7 +516,7 @@ public class TFTPServer implements Runnable
         /*
          * Handle a tftp read request.
          */
-        private void handleRead(TFTPReadRequestPacket trrp) throws IOException, TFTPPacketException
+        private void handleRead(final TFTPReadRequestPacket trrp) throws IOException, TFTPPacketException
         {
             InputStream is = null;
             try
@@ -532,13 +534,13 @@ public class TFTPServer implements Runnable
                     is = new BufferedInputStream(new FileInputStream(buildSafeFile(
                             serverReadDirectory_, trrp.getFilename(), false)));
                 }
-                catch (FileNotFoundException e)
+                catch (final FileNotFoundException e)
                 {
                     transferTftp_.bufferedSend(new TFTPErrorPacket(trrp.getAddress(), trrp
                             .getPort(), TFTPErrorPacket.FILE_NOT_FOUND, e.getMessage()));
                     return;
                 }
-                catch (Exception e)
+                catch (final Exception e)
                 {
                     transferTftp_.bufferedSend(new TFTPErrorPacket(trrp.getAddress(), trrp
                             .getPort(), TFTPErrorPacket.UNDEFINED, e.getMessage()));
@@ -550,7 +552,7 @@ public class TFTPServer implements Runnable
                     is = new ToNetASCIIInputStream(is);
                 }
 
-                byte[] temp = new byte[TFTPDataPacket.MAX_DATA_LENGTH];
+                final byte[] temp = new byte[TFTPDataPacket.MAX_DATA_LENGTH];
 
                 TFTPPacket answer;
 
@@ -601,7 +603,7 @@ public class TFTPServer implements Runnable
                         {
                             answer = transferTftp_.bufferedReceive();
                         }
-                        catch (SocketTimeoutException e)
+                        catch (final SocketTimeoutException e)
                         {
                             if (timeoutCount >= maxTimeoutRetries_)
                             {
@@ -625,34 +627,31 @@ public class TFTPServer implements Runnable
                         }
                         break;
                     }
+                    // once we get here, we know we have an answer packet
+                    // from the correct host.
+                    final TFTPAckPacket ack = (TFTPAckPacket) answer;
+                    if (ack.getBlockNumber() != block)
+                    {
+                        /*
+                         * The origional tftp spec would have called on us to resend the
+                         * previous data here, however, that causes the SAS Syndrome.
+                         * http://www.faqs.org/rfcs/rfc1123.html section 4.2.3.1 The modified
+                         * spec says that we ignore a duplicate ack. If the packet was really
+                         * lost, we will time out on receive, and resend the previous data at
+                         * that point.
+                         */
+                        sendNext = false;
+                    }
                     else
                     {
-                        // once we get here, we know we have an answer packet
-                        // from the correct host.
-                        TFTPAckPacket ack = (TFTPAckPacket) answer;
-                        if (ack.getBlockNumber() != block)
+                        // send the next block
+                        block++;
+                        if (block > 65535)
                         {
-                            /*
-                             * The origional tftp spec would have called on us to resend the
-                             * previous data here, however, that causes the SAS Syndrome.
-                             * http://www.faqs.org/rfcs/rfc1123.html section 4.2.3.1 The modified
-                             * spec says that we ignore a duplicate ack. If the packet was really
-                             * lost, we will time out on receive, and resend the previous data at
-                             * that point.
-                             */
-                            sendNext = false;
-                        }
-                        else
-                        {
-                            // send the next block
-                            block++;
-                            if (block > 65535)
-                            {
-                                // wrap the block number
-                                block = 0;
-                            }
-                            sendNext = true;
+                            // wrap the block number
+                            block = 0;
                         }
+                        sendNext = true;
                     }
                 }
             }
@@ -665,7 +664,7 @@ public class TFTPServer implements Runnable
                         is.close();
                     }
                 }
-                catch (IOException e)
+                catch (final IOException e)
                 {
                     // noop
                 }
@@ -675,7 +674,7 @@ public class TFTPServer implements Runnable
         /*
          * handle a tftp write request.
          */
-        private void handleWrite(TFTPWriteRequestPacket twrp) throws IOException,
+        private void handleWrite(final TFTPWriteRequestPacket twrp) throws IOException,
                 TFTPPacketException
         {
             OutputStream bos = null;
@@ -690,11 +689,11 @@ public class TFTPServer implements Runnable
                 }
 
                 int lastBlock = 0;
-                String fileName = twrp.getFilename();
+                final String fileName = twrp.getFilename();
 
                 try
                 {
-                    File temp = buildSafeFile(serverWriteDirectory_, fileName, true);
+                    final File temp = buildSafeFile(serverWriteDirectory_, fileName, true);
                     if (temp.exists())
                     {
                         transferTftp_.bufferedSend(new TFTPErrorPacket(twrp.getAddress(), twrp
@@ -708,7 +707,7 @@ public class TFTPServer implements Runnable
                         bos = new FromNetASCIIOutputStream(bos);
                     }
                 }
-                catch (Exception e)
+                catch (final Exception e)
                 {
                     transferTftp_.bufferedSend(new TFTPErrorPacket(twrp.getAddress(), twrp
                             .getPort(), TFTPErrorPacket.UNDEFINED, e.getMessage()));
@@ -746,7 +745,7 @@ public class TFTPServer implements Runnable
                         {
                             dataPacket = transferTftp_.bufferedReceive();
                         }
-                        catch (SocketTimeoutException e)
+                        catch (final SocketTimeoutException e)
                         {
                             if (timeoutCount >= maxTimeoutRetries_)
                             {
@@ -777,12 +776,12 @@ public class TFTPServer implements Runnable
                     }
                     else
                     {
-                        int block = ((TFTPDataPacket) dataPacket).getBlockNumber();
-                        byte[] data = ((TFTPDataPacket) dataPacket).getData();
-                        int dataLength = ((TFTPDataPacket) dataPacket).getDataLength();
-                        int dataOffset = ((TFTPDataPacket) dataPacket).getDataOffset();
+                        final int block = ((TFTPDataPacket) dataPacket).getBlockNumber();
+                        final byte[] data = ((TFTPDataPacket) dataPacket).getData();
+                        final int dataLength = ((TFTPDataPacket) dataPacket).getDataLength();
+                        final int dataOffset = ((TFTPDataPacket) dataPacket).getDataOffset();
 
-                        if (block > lastBlock || (lastBlock == 65535 && block == 0))
+                        if (block > lastBlock || lastBlock == 65535 && block == 0)
                         {
                             // it might resend a data block if it missed our ack
                             // - don't rewrite the block.
@@ -805,7 +804,7 @@ public class TFTPServer implements Runnable
                                 {
                                     dataPacket = transferTftp_.bufferedReceive();
                                 }
-                                catch (SocketTimeoutException e)
+                                catch (final SocketTimeoutException e)
                                 {
                                     // this is the expected route - the client
                                     // shouldn't be sending any more packets.
@@ -851,7 +850,7 @@ public class TFTPServer implements Runnable
          * Utility method to make sure that paths provided by tftp clients do not get outside of the
          * serverRoot directory.
          */
-        private File buildSafeFile(File serverDirectory, String fileName, boolean createSubDirs)
+        private File buildSafeFile(final File serverDirectory, final String fileName, final boolean createSubDirs)
                 throws IOException
         {
             File temp = new File(serverDirectory, fileName);
@@ -874,9 +873,9 @@ public class TFTPServer implements Runnable
         /*
          * recursively create subdirectories
          */
-        private void createDirectory(File file) throws IOException
+        private void createDirectory(final File file) throws IOException
         {
-            File parent = file.getParentFile();
+            final File parent = file.getParentFile();
             if (parent == null)
             {
                 throw new IOException("Unexpected error creating requested directory");
@@ -893,7 +892,7 @@ public class TFTPServer implements Runnable
                 {
                     return;
                 }
-                boolean result = file.mkdir();
+                final boolean result = file.mkdir();
                 if (!result)
                 {
                     throw new IOException("Couldn't create requested directory");
@@ -909,9 +908,9 @@ public class TFTPServer implements Runnable
         /*
          * recursively check to see if one directory is a parent of another.
          */
-        private boolean isSubdirectoryOf(File parent, File child)
+        private boolean isSubdirectoryOf(final File parent, final File child)
         {
-            File childsParent = child.getParentFile();
+            final File childsParent = child.getParentFile();
             if (childsParent == null)
             {
                 return false;
@@ -920,10 +919,7 @@ public class TFTPServer implements Runnable
             {
                 return true;
             }
-            else
-            {
-                return isSubdirectoryOf(parent, childsParent);
-            }
+            return isSubdirectoryOf(parent, childsParent);
         }
     }
 
@@ -932,7 +928,7 @@ public class TFTPServer implements Runnable
      *
      * @param log the stream to use for logging
      */
-    public void setLog(PrintStream log)
+    public void setLog(final PrintStream log)
     {
         this.log_ = log;
     }
@@ -942,7 +938,7 @@ public class TFTPServer implements Runnable
      *
      * @param logError the stream to use for logging errors
      */
-    public void setLogError(PrintStream logError)
+    public void setLogError(final PrintStream logError)
     {
         this.logError_ = logError;
     }
@@ -957,7 +953,7 @@ public class TFTPServer implements Runnable
     /*
      * Also allow customisation of sending data/ack so can generate errors if needed
      */
-    void sendData(TFTP tftp, TFTPPacket data) throws IOException {
+    void sendData(final TFTP tftp, final TFTPPacket data) throws IOException {
         tftp.bufferedSend(data);
     }
 }
